---
name: contingency-corner
description: Documentations that are unlikley to be useful for file-system-based agents.
---

- Interface of ImandraX other than `codelogician` CLI: 
  - `imandrax-api`: low-level Python pacakge, LLM-unfriendly
  - `imandrax-cli`: low-level CLI, LLM-unfriendly
